#
# spec file for package ghc-hslua-objectorientation
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hslua-objectorientation
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.4.0
Release:        1.1
Summary:        Object orientation tools for HsLua
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-hslua-core-devel
BuildRequires:  ghc-hslua-core-prof
BuildRequires:  ghc-hslua-marshalling-devel
BuildRequires:  ghc-hslua-marshalling-prof
BuildRequires:  ghc-hslua-typing-devel
BuildRequires:  ghc-hslua-typing-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hslua-devel
BuildRequires:  ghc-tasty-hslua-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
Expose Haskell objects to Lua with an object oriented interface.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library
development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Mon Jun 23 2025 Peter Simons <psimons@suse.com>
- Update hslua-objectorientation to version 2.4.0.
  [#]# hslua-objectorientation-2.4.0
  Released 2025-06-23.
  - The code has been reorganized: the new submodules
    `HsLua.ObjectOrientation.Generic` and
    `HsLua.ObjectOrientation.ListType` have been added.
  - The `UDTypeGeneric` type has been updated, the definitions for
    Lua types can now contain additional hooks to modify the
    behavior when initializing the type and when pushing and
    pulling objects to and from Lua.
  - The function `pushUDGeneric` is modified and no longer takes a
    `pushDocs` parameter. Use the new type hooks instead.
  - Removed the extra hook from `initTypeGeneric` and renamed it
    to `initType`. The hook, if one is needed, must now be part of
    the UDTypeGeneric object.
  - The default `__index` and `__newindex` functions have been
    simplified and no longer handle integer keys. Consequently,
    list-like types now need their own `__index` and `__newindex`
    functions. These can handle numerical indices and fall back to
    the default functions for other keys.
    The new file `hslobj.h` contains the headers of the default
    access functions. It is added to the `install-includes` cabal
    field.
* Thu Jan 18 2024 Peter Simons <psimons@suse.com>
- Update hslua-objectorientation to version 2.3.1.
  [#]# hslua-objectorientation-2.3.1
  Released 2024-01-18.
  - Relaxed upper bound for text, containers, and bytestring,
    allowing text-2.1, containers-0.7, and bytestring-0.12.
* Thu Apr 13 2023 Peter Simons <psimons@suse.com>
- Update hslua-objectorientation to version 2.3.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hslua-objectorientation-2.3.0/src/CHANGELOG.md
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Jun 19 2022 Peter Simons <psimons@suse.com>
- Update hslua-objectorientation to version 2.2.1.
  [#]# hslua-objectorientation-2.2.1
  Released 2022-06-19.
  - Require hslua-core-2.2.1.
  - Require hslua-marshalling-2.2.1.
  [#]# hslua-objectorientation-2.2.0.1
  Released 2022-05-20.
  - Relax upper bound for mtl, allow mtl-2.3.
* Sat Feb 19 2022 Peter Simons <psimons@suse.com>
- Update hslua-objectorientation to version 2.2.0.
  [#]# hslua-objectorientation-2.2.0
  Released 2022-02-19.
  - Require version 2.2 of hslua-core and hslua-marshalling.
* Fri Feb  4 2022 psimons@suse.com
- Update hslua-objectorientation to version 2.1.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hslua-objectorientation-2.1.0/src/CHANGELOG.md
* Thu Nov  4 2021 psimons@suse.com
- Update hslua-objectorientation to version 2.0.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hslua-objectorientation-2.0.1/src/CHANGELOG.md
* Mon Nov  1 2021 psimons@suse.com
- Add hslua-objectorientation at version 2.0.0.
